**************************************************
:mod:`gruvi.jsonrpc` -- JSON-RPC Client and Server
**************************************************

.. currentmodule:: gruvi.jsonrpc

.. automodule:: gruvi.jsonrpc
   :members:

   .. autodata:: REQUEST
      :annotation:

   .. autodata:: RESPONSE
      :annotation:

   .. autodata:: errorcode
      :annotation: {...}

   .. autofunction:: strerror

Example
=======

.. literalinclude:: ../examples/jsonrpc.py
    :language: python
